==> robocasa_upload-0.1.3a0-py3-none-any.whl: robocasa_upload/joylo_uploader.py <==
from .upload_func import login, create, pull, update, get_project_info
from termcolor import colored
import json, tarfile, time, datetime
import tempfile
from pathlib import Path

class JoyLoUploader:
    def __init__(self, project_name="joylo", account_path=Path("account.json").absolute()):
        self.account_path = account_path
        self.ep_hdf5 = None
        self.task_id = ""
        self.project_name = project_name
        self.project_name2uuid = {}
        self.ensure_login()
        self.upload_login()
        self.get_project_name2uuid()
        self.project_uuid = self.project_name2uuid[self.project_name]

    def ensure_login(self):
        if not self.account_path.exists():
            account_data = {}
            print(colored("empty username or password", "red"))
            account_data["username"] = input("username: ")
            account_data["password"] = input("password: ")
            with open(self.account_path, "w") as f:
                json.dump(account_data, f)

    def upload_login(self):
        with open(self.account_path, "r") as f:
            account_data = json.load(f)
        login(account_data["username"], account_data["password"])
        print(colored(f"hello {account_data['username']}!", "green"))
    
    def get_project_name2uuid(self):
        project_info = get_project_info()
        for project in project_info:
            self.project_name2uuid[project["name"]] = project["uuid"]
    
    def get_tar_name(self, task_name):
        return f"{task_name}_{int(time.time()*1e6)}.tar"
   
    def generate_tar(self, task_name, hdf5_file, running_args):
        print(colored(f"Generating tar file for {task_name}...", "yellow"))
        parent_dir = Path(hdf5_file).parent
        running_args_file = parent_dir / "running_args.json"
        json.dump(running_args, open(running_args_file, "w"))
        tar_file = parent_dir / self.get_tar_name(task_name)
        try:
            with tarfile.open(tar_file, "w") as tar:
                tar.add(hdf5_file, arcname=tar_file.stem + "/" + hdf5_file.name)
                tar.add(running_args_file, arcname=tar_file.stem + "/" + running_args_file.name)
            print(colored(f"Saved tar file to {tar_file}", "green"))
        except Exception as e:
            print(colored(f"Error generating tar file: {str(e)}", "red"))
        return tar_file
    
    def upload(self, task_name, hdf5_file, running_args={}, metadata={}, desc=""):
        tar_file = self.generate_tar(task_name, hdf5_file, running_args)
        create(tar_file.stem, tar_file, "", json.dumps(metadata), self.project_uuid, self.task_id, desc)
        print(colored(f"Successfully uploaded", "green"))

    def upload_error(self, error_message, task_name, metadata, desc=""):        
        # 创建临时目录
        tmp_dir = Path(tempfile.mkdtemp())
        # 写入错误信息到文件
        error_file = tmp_dir / "error.txt"
        error_file.write_text(error_message)
        
        # 创建tar文件
        tar_file = tmp_dir / self.get_tar_name(task_name)
        
        # 打包错误信息
        with tarfile.open(tar_file, "w") as tar:
            tar.add(error_file, arcname=tar_file.stem + "/" + error_file.name)
        if len(desc) > 100:
            desc = desc[:100]
        # 上传到服务器
        create(
            name=tar_file.stem,
            file_path=str(tar_file), 
            video_path="", 
            metadata=json.dumps(metadata), 
            project_uuid=self.project_uuid, 
            task_id=self.task_id, 
            desc=desc
        )
        
        print(colored(f"错误信息已成功上传", "green"))

    def pull_task(self, batch_name="", filters={}):
        project_uuid = self.project_name2uuid[self.project_name]
        task_info = pull(self.task_id, batch_name=batch_name, project_uuid=project_uuid, filters=filters)
        self.task_id = task_info["task_id"]
        if self.task_id == "":
            return None
        task_info.pop("task_id")
        return task_info
    
    def update_task(self, mode="reset"):
        project_uuid = self.project_name2uuid[self.project_name]
        update(self.task_id, project_uuid, mode)

==> robocasa_upload-0.1.5-py3-none-any.whl: robocasa_upload/joylo_uploader.py <==
from .upload_func import login, create, pull, update, get_project_info
from termcolor import colored
import json, tarfile, time, datetime
import tempfile
from pathlib import Path

class JoyLoUploader:
    def __init__(self, project_name="joylo", account_path=Path("account.json").absolute()):
        self.account_path = account_path
        self.ep_hdf5 = None
        self.task_id = ""
        self.project_name = project_name
        self.project_name2uuid = {}
        self.ensure_login()
        self.upload_login()
        self.get_project_name2uuid()
        self.project_uuid = self.project_name2uuid[self.project_name]

    def ensure_login(self):
        if not self.account_path.exists():
            account_data = {}
            print(colored("empty username or password", "red"))
            account_data["username"] = input("username: ")
            account_data["password"] = input("password: ")
            with open(self.account_path, "w") as f:
                json.dump(account_data, f)

    def upload_login(self):
        with open(self.account_path, "r") as f:
            account_data = json.load(f)
        login(account_data["username"], account_data["password"])
        print(colored(f"hello {account_data['username']}!", "green"))
    
    def get_project_name2uuid(self):
        project_info = get_project_info()
        for project in project_info:
            self.project_name2uuid[project["name"]] = project["uuid"]
    
    def get_tar_name(self, task_name):
        return f"{task_name}_{int(time.time()*1e6)}.tar"
   
    def generate_tar(self, task_name, hdf5_file, running_args):
        print(colored(f"Generating tar file for {task_name}...", "yellow"))
        parent_dir = Path(hdf5_file).parent
        running_args_file = parent_dir / "running_args.json"
        json.dump(running_args, open(running_args_file, "w"))
        tar_file = parent_dir / self.get_tar_name(task_name)
        try:
            with tarfile.open(tar_file, "w") as tar:
                tar.add(hdf5_file, arcname=tar_file.stem + "/" + hdf5_file.name)
                tar.add(running_args_file, arcname=tar_file.stem + "/" + running_args_file.name)
            print(colored(f"Saved tar file to {tar_file}", "green"))
        except Exception as e:
            print(colored(f"Error generating tar file: {str(e)}", "red"))
        return tar_file
    
    def upload(self, task_name, hdf5_file, running_args={}, metadata={}, desc=""):
        tar_file = self.generate_tar(task_name, hdf5_file, running_args)
        create(tar_file.stem, tar_file, "", json.dumps(metadata), self.project_uuid, self.task_id, desc, teleoperation_type=1)
        print(colored(f"Successfully uploaded", "green"))

    def upload_error(self, error_message, task_name, metadata, desc=""):        
        # 创建临时目录
        tmp_dir = Path(tempfile.mkdtemp())
        # 写入错误信息到文件
        error_file = tmp_dir / "error.txt"
        error_file.write_text(error_message)
        
        # 创建tar文件
        tar_file = tmp_dir / self.get_tar_name(task_name)
        
        # 打包错误信息
        with tarfile.open(tar_file, "w") as tar:
            tar.add(error_file, arcname=tar_file.stem + "/" + error_file.name)
        if len(desc) > 100:
            desc = desc[:100]
        # 上传到服务器
        create(
            name=tar_file.stem,
            file_path=str(tar_file), 
            video_path="", 
            metadata=json.dumps(metadata), 
            project_uuid=self.project_uuid, 
            task_id=self.task_id, 
            desc=desc,
            teleoperation_type=1
        )
        
        print(colored(f"错误信息已成功上传", "green"))

    def pull_task(self, batch_name="", filters={}):
        project_uuid = self.project_name2uuid[self.project_name]
        task_info = pull(self.task_id, batch_name=batch_name, project_uuid=project_uuid, filters=filters)
        self.task_id = task_info["task_id"]
        if self.task_id == "":
            return None
        task_info.pop("task_id")
        return task_info
    
    def update_task(self, mode="reset"):
        project_uuid = self.project_name2uuid[self.project_name]
        update(self.task_id, project_uuid, mode)
